Gemeinde Adressverwaltung GUI: Auflistung der Klassen

Gemeinde Adressverwaltung GUI

Auflistung der Klassen
Hier folgt die Aufzählung aller Klassen, Strukturen, Varianten und Schnittstellen mit einer Kurzbeschreibung:
[Detailebene 12]

▼N Gemeinde |
C Login |
C Main |
▼NGemeinde_Modelle |
C Jobs | Modelle Anwendungsübergreifend (Regelmäßige Aufgaben, Länder usw.)
C JobsSchlank |
C Gemeinde |
C Farbe |
C Gruppe |
C Anrede |
C Versandart |
C Person |
C PersonSchlank |
C Familie |
C PersonGruppe |
C PersonGruppeSchlank |
C FamilieGruppe |
C FamilieGruppeSchlank |
C GruppeAnsprechpartner |
C PersonVersandart |
C PersonVersandartSchlank |
C FamilieVersandart |
C FamilieVersandartSchlank |